<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Customer;
use App\Guest;
use Session;
use Hash;
use Carbon\Carbon;

class LoginController extends Controller
{
    public function __construct()
    {
        $this->middleware('customer')->only('logout');
    }
    public function index()
    {
        if(!Session::has('customer_id')){
            return view('website.customer.login');
        }else{
            return redirect()->back();
        }
    }
    public function login(Request $request)
    {
    	$this->validate($request, [
    		'email_or_phone' => 'required|string|max:60',
    		'password' => 'required|string|min:6'
    	]);

    	$customer = Customer::where('email', $request->email_or_phone)->orWhere('phone', $request->email_or_phone)->active()->first();
    	if($customer){
    		if(Hash::check($request->password,$customer->password)){
                $customer->updated_at = Carbon::now()->toDateTimeString();
                $customer->save();
	    		Session::put('customer_id', $customer->id);
	        	Session::flash('success', 'Login Success');
	        	return redirect('customer/dashboard');
	    	}else{
	    		Session::flash('error', 'Incorrect username or password.');
        		return redirect()->back();
	    	}
    	}else{
    		Session::flash('error', 'Incorrect username or password.');
        	return redirect()->back();
    	}
    	
    }
    public function Signin()
    {
        if(!Session::has('customer_id') || !Session::has('guest_id')){
            return view('website.customer.signin');
        }else{
            return redirect()->back();
        }
    }
    public function singninByEmail(Request $request)
    {
        $this->validate($request, [
            'email' => 'required|string|max:60',
            'e_password' => 'required|string|min:6'
        ],[
            'email.required' => 'Please enter your email',
            'e_password.required' => 'Please enter your password'
        ]);

        $customer = Customer::where('email', $request->email)->active()->first();
        if($customer){
            if(Hash::check($request->e_password,$customer->password)){
                $customer->updated_at = Carbon::now()->toDateTimeString();
                $customer->save();
                Session::put('customer_id', $customer->id);
                Session::flash('success', 'Login Success');
                return redirect('payment/method');
            }else{
                Session::flash('error', 'Incorrect email or password.');
                return redirect()->back();
            }
        }else{
            Session::flash('error', 'Incorrect email or password.');
            return redirect()->back();
        }
    }
    public function singninByPhone(Request $request)
    {
        $this->validate($request, [
            'phone' => 'required|string|max:60',
            'p_password' => 'required|string|min:6'
        ],[
            'phone.required' => 'Please enter your phone number',
            'p_password.required' => 'Please enter your password'
        ]);

        $customer = Customer::where('phone', $request->phone)->active()->first();
        if($customer){
            if(Hash::check($request->p_password,$customer->password)){
                $customer->updated_at = Carbon::now()->toDateTimeString();
                $customer->save();
                Session::put('customer_id', $customer->id);
                Session::flash('success', 'Login Success');
                return redirect('payment/method');
            }else{
                Session::flash('error', 'Incorrect phone or password.');
                return redirect()->back();
            }
        }else{
            Session::flash('error', 'Incorrect phone or password.');
            return redirect()->back();
        }
    }
    public function guest()
    {
        $guest = new Guest();
        $guest->slug = uniqid();
        $create = $guest->save();
        if($create){
            Session::put('guest_id', $guest->id);
            return redirect('payment/method');
        }else{
            Session::flash('error', 'Ops! please try again.');
            return redirect()->back();
        }
    }
    public function logout()
    {
        Session::forget('customer_id');
        return redirect('/customer/login');
    }

}
