<?php



/*
|--------------------------------------------------------------------------
| Website Routes
|--------------------------------------------------------------------------
*/
// Home Route
Route::get('/','WebsiteController@index')->name('');
// About Route
Route::get('/about','WebsiteController@about')->name('');
// Error page Route
Route::get('/error/404','WebsiteController@errorPage')->name('');
// Search Route
Route::get('search','SearchController@search')->name('');
// Contact Routes
Route::get('/contact','ContactController@index')->name('');
Route::Post('/contact','ContactController@store')->name('');
// Subscriber Route
Route::Post('/subscribe','SubscriberController@store')->name('');
// Customer login and Register Routes
Route::get('/customer/register','RegisterController@index')->name('');
Route::post('/customer/register','RegisterController@register')->name('');
Route::get('/customer/signin','LoginController@signin')->name('');
Route::post('/customer/signin/phone','LoginController@singninByPhone')->name('');
Route::post('/customer/signin/email','LoginController@singninByEmail')->name('');
Route::post('/customer/guest','LoginController@guest')->name('');
Route::get('/customer/login','LoginController@index')->name('');
Route::post('/customer/login','LoginController@login')->name('');
Route::get('/customer/logout','LoginController@logout')->name('');
// Customer Account Routes
Route::get('/customer/dashboard','CustomerController@index')->name('');
Route::get('/customer/account','CustomerController@account')->name('');
Route::post('/customer/account/edit','CustomerController@update')->name('');
Route::get('/customer/orders','CustomerController@order')->name('');
Route::get('/customer/order/details/{id}','CustomerController@show')->name('');
// Product Routes
Route::get('/product/category/{slug}','ProductController@productByMainCategory')->name('');
Route::get('/product/category/{id}/{slug}','ProductController@productByCategory')->name('');
Route::get('/product/brand/{slug}','ProductController@productByBrand')->name('');
Route::get('/product/color/{id}','ProductController@productByColor')->name('');
Route::get('/product/details/{id}/{slug}','ProductController@productDetails')->name('');
// Cart routes
Route::get('/shopping/cart','CartController@index')->name('');
Route::post('/cart/add/{id}','CartController@store')->name('');
Route::post('/cart/update','CartController@update')->name('');
Route::delete('/cart/remove/{rowId}','CartController@destroy')->name('');
// Ajax request
Route::get('/cart/items','CartController@cartItem')->name('');
// Payment method route
Route::get('/payment/method','PaymentController@index')->name('');
Route::post('/payment/method','PaymentController@store')->name('');
// Delivery method route
Route::get('/delivery/method','CheckoutController@index')->name('');
Route::post('/delivery/method','CheckoutController@store')->name('');
// Order Confirm Route
Route::get('/order/confirm','OrderController@index')->name('');
Route::post('/order/confirm','OrderController@store')->name('');
Route::get('/order/success','OrderController@orderSuccess')->name('');

// Website layout data compact
View::composer('layouts.website', function ($view) {
    $basicinfo = App\Basicinfo::first();
    $sociallink = App\Sociallink::first();
    $maincategories = App\Maincategory::limit(7)->get();
    $cartItems = Cart::content();
    $view->with('basicinfo', $basicinfo);
    $view->with('sociallink', $sociallink);
    $view->with('maincategories', $maincategories);
    $view->with('cartItems', $cartItems);
});



/*
|--------------------------------------------------------------------------
| Admin Panel Routes
|--------------------------------------------------------------------------
*/
Auth::routes();

Route::group(['prefix'=>'admin','namespace'=>'Admin','middleware'=>'auth'], function (){
    Route::get('/','AdminController@index')->name('');
    // Products Search route
    Route::get('search','SearchController@search')->name('');
    // Contact messages routes
    Route::get('contacts','ContactController@index')->name('');
    Route::get('contacts/{id}','ContactController@show')->name('');
    Route::delete('contacts/{id}','ContactController@destroy')->name('');
    // Order routes
    Route::get('orders','OrderController@index')->name('');
    Route::get('orders/today','OrderController@todayOrder')->name('');
    Route::get('orders/thismonth','OrderController@thisMonthOrder')->name('');
    Route::get('orders/thisyear','OrderController@thisyearOrder')->name('');
    Route::get('orders/{id}','OrderController@show')->name('');
    Route::delete('orders/{id}','OrderController@destroy')->name('');
    Route::get('order/cancel/{id}','OrderController@orderCancel')->name('');
    Route::get('order/delivered/{id}','OrderController@orderDelivered')->name('');
    Route::get('invoice/{id}','OrderController@invoice')->name('');
    // Customers routes
    Route::get('customers','CustomerController@index')->name('');
    Route::get('customers/{id}','CustomerController@show')->name('');
    Route::delete('customers/{id}','CustomerController@destroy')->name('');
    // Subscribers routes
    Route::get('subscribers','SubscriberController@index')->name('');
    Route::delete('subscribers/{id}','SubscriberController@destroy')->name('');
    // Products route
    Route::get('products/topsale','ProductController@topsale')->name('');
    Route::get('products/draft','ProductController@draft')->name('');
    Route::get('products/stockout','ProductController@stockout')->name('');
    Route::get('products/type/{slug}','ProductController@productType')->name('');
    // Retrive subcategories ajax request route
    Route::get('subcategories/{id}','CategoryController@subcategory')->name('');
    // Basic Info routes
    Route::get('about','AboutController@index')->name('');
    Route::put('about','AboutController@update')->name('');
    // Basic Info routes
    Route::get('basicinfo','BasicinfoController@index')->name('');
    Route::put('basicinfo','BasicinfoController@update')->name('');
    // Social media routes
    Route::get('sociallink','SociallinkController@index')->name('');
    Route::put('sociallink','SociallinkController@update')->name('');
    Route::resources([
	    'users' => 'UserController',
	    'maincategory' => 'MaincategoryController',
	    'subcategory' => 'SubcategoryController',
	    'category' => 'CategoryController',
	    'brands' => 'BrandController',
	    'products' => 'ProductController',
	    'banners' => 'BannerController',
	    'recycle/users' => 'RecycleUserController',
        'recycle/orders' => 'RecycleOrderController',
        'recycle/contacts' => 'RecycleContactController',
        'recycle/products' => 'RecycleProductController',
        'recycle/customers' => 'RecycleCustomerController',
        'recycle/banners' => 'RecycleBannerController',
	]);
});

// Admin layout data  compact
View::composer('layouts.admin', function ($view) {
    $orders = App\Order::all();
    $thisMonthTotalOrder = App\Order::thismonth()->count();
    $unreadedMessages = App\Contact::unreaded()->count();
    $contactMessages = App\Contact::latest()->get();
    $totalProduct = App\Product::all()->count();
    $topSaleProduct = App\Product::topsale()->count();
    $draftProduct = App\Product::inactive()->count();
    $stockoutProduct = App\Product::stockout()->count();
    $types = App\Type::all();
    $totalMaincategory = App\Maincategory::all()->count();
    $totalSubcategory = App\Subcategory::all()->count();
    $totalCategory = App\Category::all()->count();
    $view->with('orders', $orders);
    $view->with('unreadedMessages', $unreadedMessages);
    $view->with('contactMessages', $contactMessages);
    $view->with('totalProduct', $totalProduct);
    $view->with('topSaleProduct', $topSaleProduct);
    $view->with('draftProduct', $draftProduct);
    $view->with('stockoutProduct', $stockoutProduct);
    $view->with('types', $types);
    $view->with('totalMaincategory', $totalMaincategory);
    $view->with('totalSubcategory', $totalSubcategory);
    $view->with('totalCategory', $totalCategory);
});